@@ -1,5 +1,15 @@
 from contextlib import contextmanager
-from typing import Any, Callable, Dict, List, Optional, Union
+from typing import (
+    Any,
+    Callable,
+    Dict,
+    Generator,
+    Iterable,
+    List,
+    Mapping,
+    Optional,
+    Union,
+)
 
 from . import helpers, presets  # noqa F401
 from .common import utils  # noqa F401
@@ -28,7 +38,7 @@ _PRESETS = AttrDict(
 
 class MarkdownIt:
     def __init__(
-        self, config: Union[str, AttrDict] = "commonmark", renderer_cls=RendererHTML
+        self, config: Union[str, Mapping] = "commonmark", renderer_cls=RendererHTML
     ):
         """Main parser class
 
@@ -42,16 +52,16 @@ class MarkdownIt:
         self.renderer = renderer_cls(self)
 
         self.utils = utils
-        self.helpers = helpers
-        self.options = {}
+        self.helpers: Any = helpers
+        self.options = AttrDict()
         self.configure(config)
 
         self.linkify = linkify_it.LinkifyIt() if linkify_it else None
 
-    def __repr__(self):
+    def __repr__(self) -> str:
         return f"{self.__class__.__module__}.{self.__class__.__name__}()"
 
-    def __getitem__(self, name):
+    def __getitem__(self, name: str) -> Any:
         return {
             "inline": self.inline,
             "block": self.block,
@@ -59,7 +69,7 @@ class MarkdownIt:
             "renderer": self.renderer,
         }[name]
 
-    def set(self, options):
+    def set(self, options: AttrDict) -> None:
         """Set parser options (in the same format as in constructor).
         Probably, you will never need it, but you can change options after constructor call.
 
@@ -69,7 +79,7 @@ class MarkdownIt:
         """
         self.options = options
 
-    def configure(self, presets: Union[str, AttrDict]):
+    def configure(self, presets: Union[str, Mapping]) -> "MarkdownIt":
         """Batch load of all options and component settings.
         This is an internal method, and you probably will not need it.
         But if you will - see available presets and data structure
@@ -87,13 +97,13 @@ class MarkdownIt:
                 )
         if not presets:
             raise ValueError("Wrong `markdown-it` preset, can't be empty")
-        presets = AttrDict(presets)
+        config = AttrDict(presets)
 
-        if "options" in presets:
-            self.set(presets.options)
+        if "options" in config:
+            self.set(config.options)
 
-        if "components" in presets:
-            for name, component in presets.components.items():
+        if "components" in config:
+            for name, component in config.components.items():
                 rules = component.get("rules", None)
                 if rules:
                     self[name].ruler.enableOnly(rules)
@@ -122,7 +132,7 @@ class MarkdownIt:
         return rules
 
     def enable(
-        self, names: Union[str, List[str]], ignoreInvalid: bool = False
+        self, names: Union[str, Iterable[str]], ignoreInvalid: bool = False
     ) -> "MarkdownIt":
         """Enable list or rules. (chainable)
 
@@ -133,11 +143,10 @@ class MarkdownIt:
         containing rules with given names. If rule not found, and `ignoreInvalid`
         not set - throws exception.
 
-        ##### Example
+        Example::
+
+            md = MarkdownIt().enable(['sub', 'sup']).disable('smartquotes')
 
-        ```python
-        md = MarkdownIt()..enable(['sub', 'sup']).disable('smartquotes')
-        ```
         """
         result = []
 
@@ -155,7 +164,7 @@ class MarkdownIt:
         return self
 
     def disable(
-        self, names: Union[str, List[str]], ignoreInvalid: bool = False
+        self, names: Union[str, Iterable[str]], ignoreInvalid: bool = False
     ) -> "MarkdownIt":
         """The same as [[MarkdownIt.enable]], but turn specified rules off. (chainable)
 
@@ -178,7 +187,7 @@ class MarkdownIt:
         return self
 
     @contextmanager
-    def reset_rules(self):
+    def reset_rules(self) -> Generator[None, None, None]:
         """A context manager, that will reset the current enabled rules on exit."""
         chain_rules = self.get_active_rules()
         yield
@@ -187,13 +196,13 @@ class MarkdownIt:
                 self[chain].ruler.enableOnly(rules)
         self.inline.ruler2.enableOnly(chain_rules["inline2"])
 
-    def add_render_rule(self, name: str, function: Callable, fmt="html"):
+    def add_render_rule(self, name: str, function: Callable, fmt: str = "html") -> None:
         """Add a rule for rendering a particular Token type.
 
         Only applied when ``renderer.__output__ == fmt``
         """
         if self.renderer.__output__ == fmt:
-            self.renderer.rules[name] = function.__get__(self.renderer)
+            self.renderer.rules[name] = function.__get__(self.renderer)  # type: ignore
 
     def use(self, plugin: Callable, *params, **options) -> "MarkdownIt":
         """Load specified plugin with given params into current parser instance. (chainable)
@@ -225,7 +234,7 @@ class MarkdownIt:
         and then pass updated object to renderer.
         """
         env = AttrDict() if env is None else env
-        if not isinstance(env, AttrDict):
+        if not isinstance(env, AttrDict):  # type: ignore
             raise TypeError(f"Input data should be an AttrDict, not {type(env)}")
         if not isinstance(src, str):
             raise TypeError(f"Input data should be a string, not {type(src)}")
@@ -259,7 +268,7 @@ class MarkdownIt:
         tokens in `children` property. Also updates `env` object.
         """
         env = AttrDict() if env is None else env
-        if not isinstance(env, AttrDict):
+        if not isinstance(env, AttrDict):  # type: ignore
             raise TypeError(f"Input data should be an AttrDict, not {type(env)}")
         if not isinstance(src, str):
             raise TypeError(f"Input data should be a string, not {type(src)}")
